@@ -14,6 +14,11 @@ pub(crate) fn fetch_symbols(market_type: MarketType) -> Result<Vec<String>> {
     }
 }
 
-pub(crate) fn fetch_markets(_market_type: MarketType) -> Result<Vec<Market>> {
-    Ok(Vec::new())
+pub(crate) fn fetch_markets(market_type: MarketType) -> Result<Vec<Market>> {
+    match market_type {
+        MarketType::Spot => mxc_spot::fetch_spot_markets(),
+        MarketType::InverseSwap => mxc_swap::fetch_inverse_swap_markets(),
+        MarketType::LinearSwap => mxc_swap::fetch_linear_swap_markets(),
+        _ => panic!("Unsupported market_type: {}", market_type),
+    }
 }
