@@ -1,4 +1,5 @@
-use crypto_markets::{fetch_symbols, get_market_types, MarketType};
+use crypto_markets::{fetch_markets, fetch_symbols, get_market_types, MarketType};
+use test_case::test_case;
 
 #[macro_use]
 mod utils;
@@ -46,6 +47,7 @@ fn fetch_inverse_swap_symbols() {
     let symbols = fetch_symbols(EXCHANGE_NAME, MarketType::InverseSwap).unwrap();
     assert!(!symbols.is_empty());
     for symbol in symbols.iter() {
+        assert!(symbol.starts_with("XBT"));
         assert!(symbol.ends_with("USD") || symbol.ends_with("EUR"));
         assert_eq!(MarketType::InverseSwap, get_market_type_from_symbol(symbol));
     }
@@ -81,6 +83,7 @@ fn fetch_quanto_future_symbols() {
     let symbols = fetch_symbols(EXCHANGE_NAME, MarketType::QuantoFuture).unwrap();
     assert!(!symbols.is_empty());
     for symbol in symbols.iter() {
+        assert!(!symbol.starts_with("XBT"));
         let date = &symbol[(symbol.len() - 2)..];
         assert!(date.parse::<i64>().is_ok());
 
@@ -102,6 +105,7 @@ fn fetch_linear_future_symbols() {
     let symbols = fetch_symbols(EXCHANGE_NAME, MarketType::LinearFuture).unwrap();
     assert!(!symbols.is_empty());
     for symbol in symbols.iter() {
+        println!("{}", symbol);
         let date = &symbol[(symbol.len() - 2)..];
         assert!(date.parse::<i64>().is_ok());
         assert_eq!(
@@ -110,3 +114,24 @@ fn fetch_linear_future_symbols() {
         );
     }
 }
+
+#[test]
+fn fetch_inverse_swap_markets() {
+    let markets = fetch_markets(EXCHANGE_NAME, MarketType::InverseSwap).unwrap();
+    assert!(!markets.is_empty());
+
+    let xbtusd = markets.iter().find(|m| m.symbol == "XBTUSD").unwrap();
+    assert_eq!(xbtusd.precision.tick_size, 0.5);
+    assert_eq!(xbtusd.precision.lot_size, 100.0);
+    assert_eq!(xbtusd.contract_value, Some(1.0));
+    assert!(xbtusd.quantity_limit.is_none());
+}
+
+#[test_case(MarketType::InverseSwap)]
+#[test_case(MarketType::QuantoSwap)]
+#[test_case(MarketType::InverseFuture)]
+#[test_case(MarketType::QuantoFuture)]
+#[test_case(MarketType::LinearFuture)]
+fn test_contract_values(market_type: MarketType) {
+    check_contract_values!(EXCHANGE_NAME, market_type);
+}
